@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,14 +22,14 @@ from tencentcloud.autoscaling.v20180419 import models
 
 class AutoscalingClient(AbstractClient):
     _apiVersion = '2018-04-19'
-    _endpoint = 'as.tencentcloudapi.com'
+    _endpoint = 'as.intl.tencentcloudapi.com'
     _service = 'as'
 
 
     def AttachInstances(self, request):
-        """This API is used to add CVM instances to an auto scaling group.
+        """This interface (AttachInstances) is used to add CVM instances to a scaling group.
         * Only CVM instances in `RUNNING` or `STOPPED` status can be added.
-        * The added CVM instances must in the same VPC as the scaling group.
+        This API is used to ensure added CVM instances match the VPC network of the scaling group.
 
         :param request: Request instance for AttachInstances.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.AttachInstancesRequest`
@@ -76,9 +76,12 @@ class AutoscalingClient(AbstractClient):
 
     def CancelInstanceRefresh(self, request):
         """This API is used to cancel the instance refresh activity of the scaling group.
-        * Batches that have already been refreshed or are currently being refreshed remain unaffected; batches pending refresh will be canceled.
-        * If a refresh fails, the affected instances will remain in the standby status and require manual intervention by the user to either attempt to exit the standby status or destroy the instances.
-        * Rollback operations are not allowed after cancellation, and resuming is also unsupported.
+        * The batches that have already been refreshed remain unaffected, but the batches pending refresh will be canceled.
+        * If a batch is currently refreshing, cancellation is not allowed. You can suspend the event and wait until the current batch finishes before canceling.
+        This API is used to refresh the failed instances. If a refresh fails, the affected instances will remain in standby status, and require manual intervention to exit the standby status or terminate the instances.
+        * Rollback operations are not allowed after cancellation, and recovery is unsupported.
+        Temporarily expanded instances due to the maxSurge parameter are automatically destroyed after cancellation.
+        * During scale-in, all instances have already been updated and cannot be canceled.
 
         :param request: Request instance for CancelInstanceRefresh.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.CancelInstanceRefreshRequest`
@@ -174,8 +177,6 @@ class AutoscalingClient(AbstractClient):
     def CreateAutoScalingGroupFromInstance(self, request):
         """This API is used to create launch configurations and scaling groups based on an instance.
 
-        Note: for a scaling group that is created based on a monthly-subscribed instance, the instances added for scale-out are pay-as-you-go instance.
-
         :param request: Request instance for CreateAutoScalingGroupFromInstance.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.CreateAutoScalingGroupFromInstanceRequest`
         :rtype: :class:`tencentcloud.autoscaling.v20180419.models.CreateAutoScalingGroupFromInstanceResponse`
@@ -197,11 +198,11 @@ class AutoscalingClient(AbstractClient):
 
 
     def CreateLaunchConfiguration(self, request):
-        """This API is used to create a launch configuration.
+        """This interface (CreateLaunchConfiguration) is used to create new launch configuration.
 
-        * To modify a launch configuration, please use `ModifyLaunchConfigurationAttributes`.
+        * To modify a launch configuration, use [ModifyLaunchConfigurationAttributes](https://intl.cloud.tencent.com/document/api/377/31298?from_cn_redirect=1) to partially modify fields. If needed, create a new launch configuration.
 
-        * Up to 20 launch configurations can be created for each project. For more information, see [Usage Limits](https://intl.cloud.tencent.com/document/product/377/3120?from_cn_redirect=1).
+        By default, 50 launch configurations can be created per region. For details, see [Usage Limits](https://intl.cloud.tencent.com/document/product/377/3120?from_cn_redirect=1).
 
         :param request: Request instance for CreateLaunchConfiguration.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.CreateLaunchConfigurationRequest`
@@ -224,11 +225,11 @@ class AutoscalingClient(AbstractClient):
 
 
     def CreateLifecycleHook(self, request):
-        """This API is used to create a lifecycle hook.
+        """This interface (CreateLifecycleHook) is used for creating a lifecycle hook.
 
-        * You can configure notifications or automation commands (TAT) for the lifecycle hook.
+        * You can configure notifications or automation commands for the lifecycle hook.
 
-        If you configured a notification, Auto Scaling will notify the TDMQ queue of the following information:
+        If you configured a notification, Auto Scaling will notify the TDMQ Message Queue of the following information:.
 
         ```
         {
@@ -236,11 +237,11 @@ class AutoscalingClient(AbstractClient):
         	"Time": "2019-03-14T10:15:11Z",
         	"AppId": "1251783334",
         	"ActivityId": "asa-fznnvrja",
-        	"AutoScalingGroupId": "asg-rrrrtttt",
-        	"LifecycleHookId": "ash-xxxxyyyy",
+        	"AutoScalingGroupId": "asg-ft6y7u8n",
+        	"LifecycleHookId": "ash-p9i7y6t5",
         	"LifecycleHookName": "my-hook",
         	"LifecycleActionToken": "3080e1c9-0efe-4dd7-ad3b-90cd6618298f",
-        	"InstanceId": "ins-aaaabbbb",
+        	"InstanceId": "ins-y6dr5e43",
         	"LifecycleTransition": "INSTANCE_LAUNCHING",
         	"NotificationMetadata": ""
         }
@@ -388,7 +389,7 @@ class AutoscalingClient(AbstractClient):
     def DeleteLaunchConfiguration(self, request):
         """This API (DeleteLaunchConfiguration) is used to delete a launch configuration.
 
-        * If the launch configuration is active in an auto scaling group, it cannot be deleted.
+        * If the launch configuration is active in a scaling group, it cannot be deleted.
 
         :param request: Request instance for DeleteLaunchConfiguration.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.DeleteLaunchConfigurationRequest`
@@ -904,6 +905,32 @@ class AutoscalingClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def EnterStandby(self, request):
+        """This API is used to set instances within the scaling group to standby status.
+        Instances in standby status have a CLB weight value of 0 and will not be selected for scaling in, unhealthy replacement, or refresh operation.
+        This API is used to call the Auto Scaling power-on/power-off API which may change the standby status, while the Cloud Virtual Machine server power on/off API will not affect it.
+        The instance enters standby status, and the scaling group attempts to lower the expected number of instances, which will not be less than the minimum value.
+
+        :param request: Request instance for EnterStandby.
+        :type request: :class:`tencentcloud.autoscaling.v20180419.models.EnterStandbyRequest`
+        :rtype: :class:`tencentcloud.autoscaling.v20180419.models.EnterStandbyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("EnterStandby", params, headers=headers)
+            response = json.loads(body)
+            model = models.EnterStandbyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ExecuteScalingPolicy(self, request):
         """This API is used to execute a scaling policy.
 
@@ -932,9 +959,10 @@ class AutoscalingClient(AbstractClient):
 
 
     def ExitStandby(self, request):
-        """This API is used to exit instances from the standby status in the scaling group.
-        * When an instance is in standby status, its load balancer weight is set to 0. Upon exiting the standby status, the weight value automatically gets restored.
-        * Initiating power-on/power-off actions on instances that are in standby status also results in them exiting from the standby status.
+        """This API is used to exit instances from standby status in the scaling group.
+        * After exiting standby status, the instance enters running state and the CLB weight value is restored to the default value.
+        This API is used to call the Auto Scaling power-on/power-off API which may change the standby status, while the Cloud Virtual Machine server power on/off API will not affect it.
+        After instances exit standby status, the scaling group will raise the expected number of instances. The new expected number cannot exceed the maximum value.
 
         :param request: Request instance for ExitStandby.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.ExitStandbyRequest`
@@ -1003,10 +1031,9 @@ class AutoscalingClient(AbstractClient):
 
 
     def ModifyLaunchConfigurationAttributes(self, request):
-        """This API (ModifyLaunchConfigurationAttributes) is used to modify some attributes of a launch configuration.
+        """This API (ModifyLaunchConfigurationAttributes) is used to modify part of a launch configuration's attributes.
 
-        * The changes of launch configuration do not affect the existing instances. New instances will be created based on the modified configuration.
-        * This API supports modifying certain simple types of attributes.
+        This API is used to modify the startup configuration. Existing instances scaled out using this configuration will not change, while newly added instances using this launch configuration will scale out according to the new configuration.
 
         :param request: Request instance for ModifyLaunchConfigurationAttributes.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.ModifyLaunchConfigurationAttributesRequest`
@@ -1198,7 +1225,9 @@ class AutoscalingClient(AbstractClient):
 
 
     def ResumeInstanceRefresh(self, request):
-        """This API is used to resume the paused instance refresh activity, allowing it to retry failed instances in the current batch or proceed with refreshing subsequent batches. Note that calling this interface is ineffective when the activity is not in a paused status.
+        """This API is used to resume the paused instance refresh activity, allowing it to retry failed instances in the current batch or proceed with refreshing subsequent batches. Note that calling this API is ineffective when the activity is not in a paused status.
+
+        - When the MaxSurge parameter is used, the activity may be paused due to scale-out or scale-in failures. This API can also be used to retry scaling operations.
 
         :param request: Request instance for ResumeInstanceRefresh.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.ResumeInstanceRefreshRequest`
@@ -1221,11 +1250,12 @@ class AutoscalingClient(AbstractClient):
 
 
     def RollbackInstanceRefresh(self, request):
-        """This API is used to generate a new instance refresh activity, which also supports batched refreshing and operations such as pausing, resuming, and canceling. The interface returns the RefreshActivityId for the rollback activity.
-        * Instances pending refresh in the original activity are updated to a canceled status. Nonexistent instances are disregarded, while instances in all other statuses proceed to enter the rollback process.
-        * Instances that were being refreshed in the original activity will not be immediately terminated; instead, the rollback activity will be executed after their refresh has been completed.
-        * Rollback is supported for activities that are in a paused status or those with the most recent successful refresh; it is not supported for activities in other statuses.
-        * When the original refresh activity involves reinstalling instances, for the ImageId parameter, it will automatically restore to the image ID before the rollback; for parameters such as UserData, EnhancedService, LoginSettings, and HostName, they will still be retrieved from the launch configuration, requiring users to manually modify the launch configuration before initiating the rollback.
+        """This API is used to generate a new instance refresh activity, which also supports batch refreshing and operations such as pausing, resuming, and canceling. This API returns RefreshActivityId for the rollback activity.
+        * The instances pending refresh in the original activity are updated to canceled status. Nonexistent instances are disregarded, while instances in all other statuses proceed to enter the rollback process.
+        * The instances that are being refreshed in the original activity will not be immediately terminated. Instead, the rollback activity will be executed after their refresh complete.
+        * Rollback is supported for activities that are in the paused status or those succeeded in refreshing last time. It is not supported for activities in other statuses.
+        * When the original refresh activity involves reinstalling instances, for the ImageId parameter, it will automatically recover to the image ID before the rollback; for parameters such as UserData, EnhancedService, LoginSettings, and HostName, they will still be read from the launch configuration, requiring users to manually modify the launch configuration before initiating the rollback.
+        * The rollback activity does not support the MaxSurge parameter currently.
 
         :param request: Request instance for RollbackInstanceRefresh.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.RollbackInstanceRefreshRequest`
@@ -1411,7 +1441,8 @@ class AutoscalingClient(AbstractClient):
     def StopInstanceRefresh(self, request):
         """This API is used to pause the ongoing instance refresh activity.
         * In the paused status, the scaling group will also be disabled.
-        * Instances that are currently being updated will not be paused, instances pending updates will have their updates paused.
+        * The instances that are currently being updated or scaled out will not be paused, but instances pending updates will have their updates paused.
+        * During scale-in, all instances have already been updated and cannot be paused.
 
         :param request: Request instance for StopInstanceRefresh.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.StopInstanceRefreshRequest`
@@ -1434,9 +1465,7 @@ class AutoscalingClient(AbstractClient):
 
 
     def UpgradeLaunchConfiguration(self, request):
-        """已有替代接口ModifyLaunchConfiguration。该接口存在覆盖参数风险，目前官网已隐藏
-
-        There is a replacement API: ModifyLaunchConfiguration. This API carries the risk of parameter overwriting, and it has currently been hidden on the official website.
+        """There is a replacement API: ModifyLaunchConfiguration. This API carries the risk of parameter overwriting, and it has currently been hidden on the official website.
         This API (UpgradeLaunchConfiguration) is used to upgrade the launch configuration.
         * This API is used to upgrade the launch configuration, adopting an "entirely overwrite" approach. Regardless of previous parameter settings, they will be uniformly replaced with new configurations as specified in the interface parameters. For non-mandatory fields, if not filled in, default values will be assigned.
         * After upgrading and modifying the launch configuration, existing instances that have been scaled out using this configuration will not undergo any changes. Subsequently, newly added instances using this upgraded launch configuration will be scaled out according to the new configuration.
@@ -1462,9 +1491,9 @@ class AutoscalingClient(AbstractClient):
 
 
     def UpgradeLifecycleHook(self, request):
-        """This API (UpgradeLifecycleHook) is used to upgrade a lifecycle hook.
+        """This API is used to upgrade the lifecycle hook.
 
-        * This API is used to upgrade a lifecycle hook in a "completely overriding" manner, i.e., it uniformly sets a new configuration according to the API parameters regardless of the original parameters. If optional fields are left empty, their default values will be used.
+        * This API is used to upgrade the lifecycle hook, adopting a "comprehensive overwrite" style. Regardless of how the previous parameters were set, it uniformly uses the new configurations for API parameters. For optional fields, if they are not filled in, default values will be used.
 
         :param request: Request instance for UpgradeLifecycleHook.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.UpgradeLifecycleHookRequest`
