@@ -20,15 +20,36 @@ AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 # Operation failed.
 FAILEDOPERATION = 'FailedOperation'
 
+# The proxy payment device cannot be downgraded.
+FAILEDOPERATION_AGENTPAYDEALCANNOTDOWN = 'FailedOperation.AgentPayDealCannotDown'
+
+# The account balance is insufficient.
+FAILEDOPERATION_BALANCEINSUFFICIENT = 'FailedOperation.BalanceInsufficient'
+
 # Invalid App ID.
 FAILEDOPERATION_INVALIDAPPID = 'FailedOperation.InvalidAppId'
 
+# Order status error. Only unpaid orders support payment.
+FAILEDOPERATION_INVALIDDEAL = 'FailedOperation.InvalidDeal'
+
+# Vouchers are not available.
+FAILEDOPERATION_INVALIDVOUCHER = 'FailedOperation.InvalidVoucher'
+
+# Orders purchased together must be paid simultaneously.
+FAILEDOPERATION_NEEDPAYTOGETER = 'FailedOperation.NeedPayTogeter'
+
+# Package orders must be purchased together.
+FAILEDOPERATION_NEEDPAYTOGETHER = 'FailedOperation.NeedPayTogether'
+
 # The quantity exceeds the maximum limit.
 FAILEDOPERATION_NUMLIMITERROR = 'FailedOperation.NumLimitError'
 
 # Payment failed. Please contact Tencent Cloud to resolve this issue.
 FAILEDOPERATION_PAYPRICEERROR = 'FailedOperation.PayPriceError'
 
+# Payment succeeded but shipment failed. Please contact the cloud platform staff for handling.
+FAILEDOPERATION_PAYSUCCDELIVERFAILED = 'FailedOperation.PaySuccDeliverFailed'
+
 # Failed to get the number of data entries.
 FAILEDOPERATION_QUERYCOUNTFAILED = 'FailedOperation.QueryCountFailed'
 
@@ -68,5 +89,11 @@ OPERATIONDENIED = 'OperationDenied'
 # The account does not have CAM permission.
 UNAUTHORIZEDOPERATION_CAMNOAUTH = 'UnauthorizedOperation.CamNoAuth'
 
+# Due to account security upgrade, purchase cloud resources requires complete real-name information.
+UNAUTHORIZEDOPERATION_CERTIFICATIONNEEDUPGRADE = 'UnauthorizedOperation.CertificationNeedUpgrade'
+
+# The account has not been real-name authenticated, and payment failed.
+UNAUTHORIZEDOPERATION_NOTCERTIFICATION = 'UnauthorizedOperation.NotCertification'
+
 # Operation unsupported.
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
