@@ -14,10 +14,12 @@
 
 
 class HttpProfile(object):
+    scheme = "https"
+
     def __init__(self, protocol=None, endpoint=None, reqMethod="POST", reqTimeout=60,
-                 keepAlive=False):
+                 keepAlive=False, proxy=None, rootDomain=None, certification=None):
         """HTTP profile.
-        :param protocol: temporarily useless,set None
+        :param protocol: http or https, default is https.
         :type protocol: str
         :param endpoint: The domain to access, like: cvm.tencentcloudapi.com
         :type endpoint: str
@@ -25,10 +27,17 @@ class HttpProfile(object):
         :type reqMethod: str
         :param reqTimeout: The http timeout in second.
         :type reqTimeout: int
+        :param rootDomain: The root domain to access, like: tencentcloudapi.com.
+        :type rootDomain: str
         """
         self.endpoint = endpoint
         self.reqTimeout = 60 if reqTimeout is None else reqTimeout
         self.reqMethod = "POST" if reqMethod is None else reqMethod
-        self.protocol = protocol
+        self.protocol = protocol or "https"
+        # protocol is not precise word according to rfc
+        self.scheme = self.protocol
         self.keepAlive = keepAlive
-
+        self.proxy = proxy
+        self.rootDomain = "intl.tencentcloudapi.com" if rootDomain is None else rootDomain
+        self.certification = certification
+        self.apigw_endpoint = None
