@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,28 +14,40 @@
 # limitations under the License.
 
 
+# Authentication failed.
+AUTHFAILURE_AUTHFAILUREERROR = 'AuthFailure.AuthFailureError'
+
 # The current user is not allowed to perform this operation as the authentication failed.
 AUTHFAILURE_UNAUTHORIZEDOPERATIONERROR = 'AuthFailure.UnauthorizedOperationError'
 
+# The operation failed.
+FAILEDOPERATION_FAILEDOPERATIONERROR = 'FailedOperation.FailedOperationError'
+
 # This operation is prohibited.
 FAILEDOPERATION_NOTALLOWOPERATION = 'FailedOperation.NotAllowOperation'
 
+# 
+FAILEDOPERATION_PROXYERROR = 'FailedOperation.ProxyError'
+
 # Failed to start the task.
 FAILEDOPERATION_STARTJOBFAILED = 'FailedOperation.StartJobFailed'
 
-# This operation cannot be performed due to status conflict.
+# This operation cannot be performed due to a status conflict.
 FAILEDOPERATION_STATUSINCONFLICT = 'FailedOperation.StatusInConflict'
 
+# 
+FAILEDOPERATION_STATUSINCONFLICTERROR = 'FailedOperation.StatusInConflictError'
+
 # An internal error occurred.
 INTERNALERROR = 'InternalError'
 
 # Failed to create the async task.
 INTERNALERROR_ADDTASKERROR = 'InternalError.AddTaskError'
 
-# Internal scheduling system error.
+# An internal scheduling system error occurred.
 INTERNALERROR_CELERYERROR = 'InternalError.CeleryError'
 
-# CGW system error.
+# A CGW system error occurred.
 INTERNALERROR_CGWSYSTEMERROR = 'InternalError.CgwSystemError'
 
 # Failed to access the database on the DTS platform.
@@ -44,19 +56,31 @@ INTERNALERROR_DATABASEERROR = 'InternalError.DatabaseError'
 # Migration tasks are in conflict.
 INTERNALERROR_DUPLICATEJOB = 'InternalError.DuplicateJob'
 
+# An internal error occurred.
+INTERNALERROR_INTERNALERRORERROR = 'InternalError.InternalErrorError'
+
+# An HTTP access request error occurred.
+INTERNALERROR_INTERNALHTTPSERVERERROR = 'InternalError.InternalHttpServerError'
+
+# An error occurred while accessing the internal component.
+INTERNALERROR_INTERNALINNERCOMMONERROR = 'InternalError.InternalInnerCommonError'
+
+# Failed to call the billing service.
+INTERNALERROR_INTERNALTRADEERROR = 'InternalError.InternalTradeError'
+
 # Locks are in conflict.
 INTERNALERROR_LOCKERROR = 'InternalError.LockError'
 
-# Communication protocol error.
+# A communication protocol error occurred.
 INTERNALERROR_PROTOCOLERROR = 'InternalError.ProtocolError'
 
-# Internal error.
+# An internal error occurred.
 INTERNALERROR_UNDEFINEDERROR = 'InternalError.UndefinedError'
 
-# Unknown internal error.
+# An unknown internal error occurred.
 INTERNALERROR_UNKNOWNERROR = 'InternalError.UnknownError'
 
-# A parameter error occurred.
+# The parameter is incorrect.
 INVALIDPARAMETER = 'InvalidParameter'
 
 # Parameter value error.
@@ -65,41 +89,74 @@ INVALIDPARAMETER_BIZINVALIDPARAMETERVALUEERROR = 'InvalidParameter.BizInvalidPar
 # The instance does not exist.
 INVALIDPARAMETER_INSTANCENOTFOUND = 'InvalidParameter.InstanceNotFound'
 
-# Incorrect parameter value.
+# 
+INVALIDPARAMETER_INVALIDIPADDRESS = 'InvalidParameter.InvalidIpAddress'
+
+# The parameter is invalid.
+INVALIDPARAMETER_INVALIDPARAMETERERROR = 'InvalidParameter.InvalidParameterError'
+
+# 
+INVALIDPARAMETERVALUE_BIZINVALIDPARAMETERVALUEERROR = 'InvalidParameterValue.BizInvalidParameterValueError'
+
+# A data conversion error occurred.
+INVALIDPARAMETERVALUE_DATACONVERTERROR = 'InvalidParameterValue.DataConvertError'
+
+# The parameter value is incorrect.
 INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUE = 'InvalidParameterValue.InvalidParameterValue'
 
+# The parameter is invalid.
+INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUEERROR = 'InvalidParameterValue.InvalidParameterValueError'
+
 # The number of idle migration tasks exceeds the limit.
 LIMITEXCEEDED_MAXUNUSEDJOBS = 'LimitExceeded.MaxUnusedJobs'
 
-# Operation denied.
+# The operation was denied.
 OPERATIONDENIED = 'OperationDenied'
 
 # The operation was denied as the condition was not met.
 OPERATIONDENIED_BIZOPERATIONDENIEDERROR = 'OperationDenied.BizOperationDeniedError'
 
-# Task operation failure.
+# The task operation failed.
 OPERATIONDENIED_JOBOPERATIONDENIEDERROR = 'OperationDenied.JobOperationDeniedError'
 
 # DTS does not support the current migration type.
 OPERATIONDENIED_MIGRATESERVICESUPPORTERROR = 'OperationDenied.MigrateServiceSupportError'
 
+# The account balance is insufficient.
+OPERATIONDENIED_NOTENOUGHMONEYERROR = 'OperationDenied.NotEnoughMoneyError'
+
 # This operation cannot be performed.
 OPERATIONDENIED_OPERATIONDENIED = 'OperationDenied.OperationDenied'
 
+# The operation was denied.
+OPERATIONDENIED_OPERATIONDENIEDERROR = 'OperationDenied.OperationDeniedError'
+
+# The number of requests exceeds the limit.
+REQUESTLIMITEXCEEDED_REQUESTLIMITEXCEEDEDERROR = 'RequestLimitExceeded.RequestLimitExceededError'
+
 # The resource does not exist.
 RESOURCENOTFOUND = 'ResourceNotFound'
 
-# Resource not found.
+# The resource was not found.
 RESOURCENOTFOUND_BIZRESOURCENOTFOUNDERROR = 'ResourceNotFound.BizResourceNotFoundError'
 
 # The migration task does not exist.
 RESOURCENOTFOUND_JOBNOTEXIST = 'ResourceNotFound.JobNotExist'
 
-# The instance is not found.
+# The instance was not found.
 RESOURCENOTFOUND_RESOURCENOTFOUND = 'ResourceNotFound.ResourceNotFound'
 
-# Verification failed. Insufficient permissions.
+# The resource was not found.
+RESOURCENOTFOUND_RESOURCENOTFOUNDERROR = 'ResourceNotFound.ResourceNotFoundError'
+
+# Authentication failed as there were no required permissions.
 UNAUTHORIZEDOPERATION_NOTENOUGHPRIVILEGES = 'UnauthorizedOperation.NotEnoughPrivileges'
 
-# Unsupported operation
+# The operation is unauthorized.
+UNAUTHORIZEDOPERATION_UNAUTHORIZEDOPERATIONERROR = 'UnauthorizedOperation.UnauthorizedOperationError'
+
+# The operation is not supported.
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
+# The intranet user did not specify the required tags when creating the migration task. The **department**, **product**, and **owner** tags must be specified.
+UNSUPPORTEDOPERATION_INTRANETUSERNOTTAGGEDERROR = 'UnsupportedOperation.IntraNetUserNotTaggedError'
