@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ from tencentcloud.mdl.v20200326 import models
 
 class MdlClient(AbstractClient):
     _apiVersion = '2020-03-26'
-    _endpoint = 'mdl.tencentcloudapi.com'
+    _endpoint = 'mdl.intl.tencentcloudapi.com'
     _service = 'mdl'
 
 
@@ -256,29 +256,6 @@ class MdlClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DescribeMediaLiveHighlightResult(self, request):
-        """Query the highlight result information corresponding to the media live broadcast channel.
-
-        :param request: Request instance for DescribeMediaLiveHighlightResult.
-        :type request: :class:`tencentcloud.mdl.v20200326.models.DescribeMediaLiveHighlightResultRequest`
-        :rtype: :class:`tencentcloud.mdl.v20200326.models.DescribeMediaLiveHighlightResultResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeMediaLiveHighlightResult", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeMediaLiveHighlightResultResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def DescribeStreamLiveChannel(self, request):
         """This API is used to query a StreamLive channel.
 
@@ -624,6 +601,29 @@ class MdlClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def GetAbWatermarkPlayUrl(self, request):
+        """Get AB watermark play url.
+
+        :param request: Request instance for GetAbWatermarkPlayUrl.
+        :type request: :class:`tencentcloud.mdl.v20200326.models.GetAbWatermarkPlayUrlRequest`
+        :rtype: :class:`tencentcloud.mdl.v20200326.models.GetAbWatermarkPlayUrlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetAbWatermarkPlayUrl", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetAbWatermarkPlayUrlResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyStreamLiveChannel(self, request):
         """This API is used to modify a StreamLive channel.
 
