@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ from tencentcloud.ocr.v20181119 import models
 
 class OcrClient(AbstractClient):
     _apiVersion = '2018-11-19'
-    _endpoint = 'ocr.tencentcloudapi.com'
+    _endpoint = 'ocr.intl.tencentcloudapi.com'
     _service = 'ocr'
 
 
@@ -51,6 +51,33 @@ class OcrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ExtractDocMulti(self, request):
+        """This API supports identifying and extracting field information in structured scenarios such as complex scenarios and multiple formats. Key scenarios include: finance, health care, transportation, travel, insurance. Click [experience now](https://ocrdemo.cloud.tencent.com/).
+
+        This API is used to set the alias SmartStructuralPro.
+
+        The default API request rate limit is 5 requests per second.
+
+        :param request: Request instance for ExtractDocMulti.
+        :type request: :class:`tencentcloud.ocr.v20181119.models.ExtractDocMultiRequest`
+        :rtype: :class:`tencentcloud.ocr.v20181119.models.ExtractDocMultiResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ExtractDocMulti", params, headers=headers)
+            response = json.loads(body)
+            model = models.ExtractDocMultiResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def GeneralAccurateOCR(self, request):
         """This API is used to detect and recognize characters in an image. It can recognize Chinese, English, Chinese-English, digits, and special symbols and return the text box positions and characters.
 
@@ -281,6 +308,7 @@ class OcrClient(AbstractClient):
 
     def MLIDPassportOCR(self, request):
         """This API is used to recognize a passport issued in Hong Kong/Macao/Taiwan (China) or other countries/regions. Recognizable fields include passport ID, name, date of birth, gender, expiration date, issuing country/region, and nationality. It has the features of cropping identity photos and alarming for photographed or photocopied documents.
+        This interface supports regional scope: countries with machine-readable passports
 
         :param request: Request instance for MLIDPassportOCR.
         :type request: :class:`tencentcloud.ocr.v20181119.models.MLIDPassportOCRRequest`
@@ -352,6 +380,98 @@ class OcrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RecognizeBrazilDriverLicenseOCR(self, request):
+        """This interface supports identification of the front and back of Brazilian driver's license. The identification fields include name, driver's license category, number, validity period, etc.
+
+        :param request: Request instance for RecognizeBrazilDriverLicenseOCR.
+        :type request: :class:`tencentcloud.ocr.v20181119.models.RecognizeBrazilDriverLicenseOCRRequest`
+        :rtype: :class:`tencentcloud.ocr.v20181119.models.RecognizeBrazilDriverLicenseOCRResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RecognizeBrazilDriverLicenseOCR", params, headers=headers)
+            response = json.loads(body)
+            model = models.RecognizeBrazilDriverLicenseOCRResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def RecognizeBrazilIDCardOCR(self, request):
+        """This interface supports identification of the front and back of Brazilian ID license. The identification fields include name, driver's license category, number, validity period, etc.
+
+        :param request: Request instance for RecognizeBrazilIDCardOCR.
+        :type request: :class:`tencentcloud.ocr.v20181119.models.RecognizeBrazilIDCardOCRRequest`
+        :rtype: :class:`tencentcloud.ocr.v20181119.models.RecognizeBrazilIDCardOCRResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RecognizeBrazilIDCardOCR", params, headers=headers)
+            response = json.loads(body)
+            model = models.RecognizeBrazilIDCardOCRResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def RecognizeBrazilRNEOCR(self, request):
+        """Brazil RNE document recognition Default interface request frequency limit: 5 times/second
+
+        :param request: Request instance for RecognizeBrazilRNEOCR.
+        :type request: :class:`tencentcloud.ocr.v20181119.models.RecognizeBrazilRNEOCRRequest`
+        :rtype: :class:`tencentcloud.ocr.v20181119.models.RecognizeBrazilRNEOCRResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RecognizeBrazilRNEOCR", params, headers=headers)
+            response = json.loads(body)
+            model = models.RecognizeBrazilRNEOCRResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def RecognizeBrazilRNMOCR(self, request):
+        """This interface supports identification of the front and back of Brazilian RNM license. The default interface request frequency limit is 5 times per second.
+
+        :param request: Request instance for RecognizeBrazilRNMOCR.
+        :type request: :class:`tencentcloud.ocr.v20181119.models.RecognizeBrazilRNMOCRRequest`
+        :rtype: :class:`tencentcloud.ocr.v20181119.models.RecognizeBrazilRNMOCRResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RecognizeBrazilRNMOCR", params, headers=headers)
+            response = json.loads(body)
+            model = models.RecognizeBrazilRNMOCRResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def RecognizeGeneralInvoice(self, request):
         """This API is used to recognize various types of invoices or tickets in an image or PDF file. You can also specify a type. 14 types of standard expense reimbursement invoices are supported, including value-added tax (VAT) invoice (special, general, roll, blockchain, and toll), fully digitalized electronic invoice (special and general), non-tax revenue invoice (general receipt and general payment voucher), quota invoice, general machine-printed invoice, car sales invoice (motor vehicle sales invoice and used car invoice), train ticket, taxi receipt, itinerary/receipt of e-ticket for air transportation, bus ticket, ship ticket, toll receipt, and medical invoice (inpatient and outpatient). This API can also be used for intelligent recognition of other types of invoices. To try now, click [here](https://intl.cloud.tencent.com/product/ocr?from_cn_redirect=1).
 
@@ -621,6 +741,29 @@ class OcrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RecognizeMexicoVTID(self, request):
+        """This interface supports identification of the front and back of Mexican Voter ID Card. The default interface request frequency limit is 5 times per second.
+
+        :param request: Request instance for RecognizeMexicoVTID.
+        :type request: :class:`tencentcloud.ocr.v20181119.models.RecognizeMexicoVTIDRequest`
+        :rtype: :class:`tencentcloud.ocr.v20181119.models.RecognizeMexicoVTIDResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RecognizeMexicoVTID", params, headers=headers)
+            response = json.loads(body)
+            model = models.RecognizeMexicoVTIDResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def RecognizePhilippinesDrivingLicenseOCR(self, request):
         """This API is used to recognize a Philippine driver's license.
 
@@ -789,7 +932,6 @@ class OcrClient(AbstractClient):
 
     def RecognizeThaiIDCardOCR(self, request):
         """This API is used to recognize the fields on a Thai identity card, including name in Thai, name in English, address, date of birth, identification number, date of issue, and date of expiry.
-        Currently, this API is not generally available. For more information, please [contact your sales rep](https://intl.cloud.tencent.com/about/connect?from_cn_redirect=1).
 
         A maximum of 10 requests can be initiated per second for this API.
 
@@ -813,6 +955,32 @@ class OcrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RecognizeThaiPinkCard(self, request):
+        """This API is used to recognize the fields on a Thai identity card, including name in Thai, name in English, address, date of birth, identification number, date of issue, and date of expiry.
+        Currently, this API is not generally available. For more information, please [contact your sales rep](https://intl.cloud.tencent.com/about/connect?from_cn_redirect=1).
+
+        A maximum of 5 requests can be initiated per second for this API.
+
+        :param request: Request instance for RecognizeThaiPinkCard.
+        :type request: :class:`tencentcloud.ocr.v20181119.models.RecognizeThaiPinkCardRequest`
+        :rtype: :class:`tencentcloud.ocr.v20181119.models.RecognizeThaiPinkCardResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RecognizeThaiPinkCard", params, headers=headers)
+            response = json.loads(body)
+            model = models.RecognizeThaiPinkCardResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def SealOCR(self, request):
         """This API is used to recognize various types of seals, including invoice seals and finance seals. It is suitable for scenarios such as official document and invoice/ticket OCR.
 
@@ -863,6 +1031,31 @@ class OcrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def SmartStructuralPro(self, request):
+        """This API is used to recognize fields from cards, documents, bills, forms, contracts, and other structured information. It is flexible and efficient to use, without any configuration required. This API is suitable for recognizing structured information.
+
+        A maximum of 10 requests can be initiated per second for this API.
+
+        :param request: Request instance for SmartStructuralPro.
+        :type request: :class:`tencentcloud.ocr.v20181119.models.SmartStructuralProRequest`
+        :rtype: :class:`tencentcloud.ocr.v20181119.models.SmartStructuralProResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SmartStructuralPro", params, headers=headers)
+            response = json.loads(body)
+            model = models.SmartStructuralProResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def TableOCR(self, request):
         """This API is used to detect and recognize Chinese and English forms in images. It can return the text content of each cell and save the recognition result as Excel.
 
