@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -194,6 +194,9 @@ INVALIDPARAMETERVALUE_SECURITYGROUPIDISILLEGAL = 'InvalidParameterValue.Security
 # The database limit is exceeded.
 LIMITEXCEEDED_TOOMANYDB = 'LimitExceeded.TooManyDB'
 
+# Error of missing parameters.
+MISSINGPARAMETER = 'MissingParameter'
+
 # An incremental backup import task to be started already exists.
 RESOURCEINUSE_INCREMENTALMIGRATIONEXIST = 'ResourceInUse.IncrementalMigrationExist'
 
