@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,6 +26,9 @@ FAILEDOPERATION = 'FailedOperation'
 # You do not have permission to perform this operation.
 FAILEDOPERATION_AUTHERROR = 'FailedOperation.AuthError'
 
+# Cannot be deleted when there are unbound cloud resources.
+FAILEDOPERATION_BOUNDRESOURCES = 'FailedOperation.BoundResources'
+
 # A CAM authentication error occurred.
 FAILEDOPERATION_CAMAUTHORIZEDFAIL = 'FailedOperation.CAMAuthorizedFail'
 
@@ -41,6 +44,9 @@ FAILEDOPERATION_CANNOTBEDELETEDWITHINHOUR = 'FailedOperation.CannotBeDeletedWith
 # Failed to get order information. Try again later.
 FAILEDOPERATION_CANNOTGETORDER = 'FailedOperation.CannotGetOrder'
 
+# Note: the uploaded certificate content does not conform to the standard format of ca certificates. please check whether the certificate type is incorrect.
+FAILEDOPERATION_CERTIFICATECAERROR = 'FailedOperation.CertificateCaError'
+
 # This operation can be performed only when the record status is Complete.
 FAILEDOPERATION_CERTIFICATEDEPLOYDETAILROLLBACKSTATUSINVALID = 'FailedOperation.CertificateDeployDetailRollbackStatusInvalid'
 
@@ -80,6 +86,9 @@ FAILEDOPERATION_CERTIFICATEHOSTRESOURCETYPEINVALID = 'FailedOperation.Certificat
 # The certificate is invalid.
 FAILEDOPERATION_CERTIFICATEINVALID = 'FailedOperation.CertificateInvalid'
 
+# Note: the certificate content and private key do not match. please check (pay attention to whether there are extra spaces).
+FAILEDOPERATION_CERTIFICATEMATCHERROR = 'FailedOperation.CertificateMatchError'
+
 # The certificate and the private key do not match.
 FAILEDOPERATION_CERTIFICATEMISMATCH = 'FailedOperation.CertificateMismatch'
 
@@ -95,15 +104,24 @@ FAILEDOPERATION_CERTIFICATENOTFOUND = 'FailedOperation.CertificateNotFound'
 # The certificate does not exist, or the review cannot be canceled.
 FAILEDOPERATION_CERTIFICATENOTFOUNDORCANTCANCEL = 'FailedOperation.CertificateNotFoundOrCantCancel'
 
+# Parsing failed. check if the certificate meets the standard and pay attention to whether there are extra spaces.
+FAILEDOPERATION_CERTIFICATEPARSEERROR = 'FailedOperation.CertificateParseError'
+
 # You cannot re-submit a review application for a certificate in this status.
 FAILEDOPERATION_CERTIFICATESTATUSNOTALLOWRESUBMIT = 'FailedOperation.CertificateStatusNotAllowResubmit'
 
+# The cert associated with the cloud resource query task id is invalid.
+FAILEDOPERATION_CERTIFICATESYNCTASKIDINVALID = 'FailedOperation.CertificateSyncTaskIdInvalid'
+
 # The confirmation letter file cannot exceed 1.4 MB.
 FAILEDOPERATION_CONFIRMLETTERTOOLARGE = 'FailedOperation.ConfirmLetterTooLarge'
 
 # The confirmation letter file cannot be smaller than 1 KB.
 FAILEDOPERATION_CONFIRMLETTERTOOSMALL = 'FailedOperation.ConfirmLetterTooSmall'
 
+# Cannot be deleted when the free cert application time has not exceeded 1 hour.
+FAILEDOPERATION_DELETEFAILEDTIMENOTUP = 'FailedOperation.DeleteFailedTimeNotUp'
+
 # The certificate is associated with a Tencent Cloud resource and cannot be deleted.
 FAILEDOPERATION_DELETERESOURCEFAILED = 'FailedOperation.DeleteResourceFailed'
 
@@ -152,6 +170,9 @@ FAILEDOPERATION_PACKAGEEXPIRED = 'FailedOperation.PackageExpired'
 # The benefit package does not exist.
 FAILEDOPERATION_PACKAGENOTFOUND = 'FailedOperation.PackageNotFound'
 
+# Cannot perform deletion when the renewed cert has not been issued.
+FAILEDOPERATION_RENEWNOTISSUED = 'FailedOperation.RenewNotIssued'
+
 # The role does not exist. Please authorize the role first.
 FAILEDOPERATION_ROLENOTFOUNDAUTHORIZATION = 'FailedOperation.RoleNotFoundAuthorization'
 
@@ -173,6 +194,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # u200cYou cannot re-submit a review application for a certificate in this status.
 INVALIDPARAMETER_CERTIFICATESTATUSNOTALLOWRESUBMIT = 'InvalidParameter.CertificateStatusNotAllowResubmit'
 
+# Number of certificates exceed the limit.
+INVALIDPARAMETER_CERTIFICATESNUMBEREXCEEDED = 'InvalidParameter.CertificatesNumberExceeded'
+
 # Incorrect CSR ID.
 INVALIDPARAMETER_INVALIDCSRID = 'InvalidParameter.InvalidCSRId'
 
@@ -191,6 +215,9 @@ INVALIDPARAMETER_WITHDETAILREASON = 'InvalidParameter.WithDetailReason'
 # Invalid parameter value.
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# Intermediate certificate inconsistent.
+INVALIDPARAMETERVALUE_INTERMEDIATECERTNOTSAME = 'InvalidParameterValue.IntermediateCertNotSame'
+
 # The API rate limit is reached.
 LIMITEXCEEDED_RATELIMITEXCEEDED = 'LimitExceeded.RateLimitExceeded'
 
