@@ -750,6 +750,8 @@ Note: This field may return null, indicating that no valid values can be obtaine
         :type ContextText: str
         :param _SentimentAnalysis: 
         :type SentimentAnalysis: :class:`tencentcloud.tms.v20201229.models.SentimentAnalysis`
+        :param _HitType: 
+        :type HitType: str
         :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
@@ -765,6 +767,7 @@ Note: This field may return null, indicating that no valid values can be obtaine
         self._SubLabel = None
         self._ContextText = None
         self._SentimentAnalysis = None
+        self._HitType = None
         self._RequestId = None
 
     @property
@@ -906,6 +909,17 @@ Note: This field may return null, indicating that no valid values can be obtaine
     def SentimentAnalysis(self, SentimentAnalysis):
         self._SentimentAnalysis = SentimentAnalysis
 
+    @property
+    def HitType(self):
+        """
+        :rtype: str
+        """
+        return self._HitType
+
+    @HitType.setter
+    def HitType(self, HitType):
+        self._HitType = HitType
+
     @property
     def RequestId(self):
         """The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
@@ -943,6 +957,7 @@ Note: This field may return null, indicating that no valid values can be obtaine
         if params.get("SentimentAnalysis") is not None:
             self._SentimentAnalysis = SentimentAnalysis()
             self._SentimentAnalysis._deserialize(params.get("SentimentAnalysis"))
+        self._HitType = params.get("HitType")
         self._RequestId = params.get("RequestId")
 
 
